About
===========

This is a Travelling Salesman Problem (TSP) solver with the core logic written in C++ and then using Python bindings.
It uses iterative stochastic local search to find a near-optimal solution to the TSP in a reasonable amount of time.

It is extremely fast and provides solutions that are of high quality compared to other available modules.
See the comparisons for more details.

As of current development, the solver has reached state-of-the-art (SOTA) performance.
